@@ -1,29 +1,21 @@
 
-Plotar2D=function(D,m=2,niveis,n,xlab=NULL,ylab=NULL,zlab=NULL,Metodo,
-                  contour,col.contour,cor,box,main){
-
-  modelos=list(
-    m1  =y~   1 + A  + B,
-    m2  =y~	 1 + A  + I(A^2)  + B,
-    m3	=y~	 1 + A  + B       + I(B^2),
-    m4	=y~	 1 + A  + I(A^2)  + B  + I(B^2),
-    m5	=y~	 1 + A  + B       + A:B,
-    m6	=y~	 1 + A  + I(A^2)  + B  + A:B,
-    m7	=y~	 1 + A  + B       + I(B^2)  + A:B,
-    m8	=y~	 1 + A  + I(A^2)  + B  + I(B^2)  + A:B,
-    m9	=y~	 1 + A  + I(A^2)  + B  + I(B^2)  + A:B  + I(A^2):B,
-    m10	=y~	 1 + A  + I(A^2)  + B  + I(B^2)  + A:B  + I(B^2):A,
-    m11	=y~	 1 + A  + I(A^2)  + B  + I(B^2)  + A:B  + I(A^2):B  +  I(B^2):A,
-    m12	=y~	 1 + A  + I(A^2)  + B  + I(B^2)  + A:B  + I(A^2):B  +  I(B^2):A + I(A^2):I(B^2))
-  #########################################################################################
-  A=D[,1]
-  B=D[,2]
-  y=D[,3]
-
-  model=lm(modelos[[m]])
+Plotar2D=function(D,m,niveis,n,xlab=NULL,ylab=NULL,zlab=NULL,Metodo,
+                  contour,col.contour,cor,box,main=NULL){
 
 
-  XY=expand.grid(A=seq(min(A),max(A),l=n),B=seq(min(B),max(B),l=n))
+
+
+
+
+  X=D[,1]
+  Y=D[,2]
+  Z=D[,3]
+
+  DD=data.frame(X=X,Y=Y,Z=Z)
+  model=lm(m,data=DD)
+
+
+  XY=expand.grid(X=seq(min(X),max(X),l=n),Y=seq(min(Y),max(Y),l=n))
   XYZ=cbind(XY,Yp=predict(model,newdata = XY))
 
   z=matrix(XYZ$Yp,ncol=n)
@@ -42,8 +34,8 @@ Plotar2D=function(D,m=2,niveis,n,xlab=NULL,ylab=NULL,zlab=NULL,Metodo,
   # Recode facet z-values into color indices
   facetcol <- cut(zfacet, nbcol)
 
-  x=unique(XYZ$A)
-  y=unique(XYZ$B)
+  x=unique(XYZ$X)
+  y=unique(XYZ$Y)
 
   if(is.null(xlab)){xlab=colnames(D)[1]}
    if(is.null(ylab)){ylab=colnames(D)[2]}
